@@ -483,7 +483,7 @@ void KdenliveSettingsDialog::initSdlPage(bool gpuAllowed)
     connect(m_configSdl.reload_blackmagic, &QAbstractButton::clicked, this, &KdenliveSettingsDialog::slotReloadBlackMagic);
     // m_configSdl.kcfg_openglmonitors->setHidden(true);
     connect(m_configSdl.fullscreen_monitor, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this,
-            &KdenliveSettingsDialog::slotSetFullscreenMonitor);
+            &KdenliveSettingsDialog::slotDialogModified);
     connect(m_configSdl.kcfg_audio_driver, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this,
             &KdenliveSettingsDialog::slotCheckAlsaDriver);
     connect(m_configSdl.kcfg_audio_backend, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this,
@@ -730,7 +730,19 @@ void KdenliveSettingsDialog::initDevices()
     }
 
     m_configSdl.kcfg_audio_backend->addItem(i18n("SDL"), KdenliveSettings::sdlAudioBackend());
-    m_configSdl.kcfg_audio_backend->addItem(i18n("RtAudio"), "rtaudio");
+    if (KdenliveSettings::consumerslist().isEmpty()) {
+        Mlt::Properties *consumers = pCore->getMltRepository()->consumers();
+        QStringList consumersItemList;
+        consumersItemList.reserve(consumers->count());
+        for (int i = 0; i < consumers->count(); ++i) {
+            consumersItemList << consumers->get_name(i);
+        }
+        delete consumers;
+        KdenliveSettings::setConsumerslist(consumersItemList);
+    }
+    if (KdenliveSettings::consumerslist().contains("rtaudio")) {
+        m_configSdl.kcfg_audio_backend->addItem(i18n("RtAudio"), "rtaudio");
+    }
 
     if (!KdenliveSettings::audiobackend().isEmpty()) {
         int ix = m_configSdl.kcfg_audio_backend->findData(KdenliveSettings::audiobackend());
@@ -740,22 +752,44 @@ void KdenliveSettingsDialog::initDevices()
     m_configSdl.group_sdl->setEnabled(KdenliveSettings::audiobackend().startsWith(QLatin1String("sdl")));
     
     // Fill monitors data
+    fillMonitorData();
+    connect(qApp, &QApplication::screenAdded, this, &KdenliveSettingsDialog::fillMonitorData);
+    connect(qApp, &QApplication::screenRemoved, this, &KdenliveSettingsDialog::fillMonitorData);
+    loadCurrentV4lProfileInfo();
+}
+
+
+
+void KdenliveSettingsDialog::fillMonitorData()
+{
     QSignalBlocker bk(m_configSdl.fullscreen_monitor);
     m_configSdl.fullscreen_monitor->clear();
     m_configSdl.fullscreen_monitor->addItem(i18n("auto"));
+    int ix = 0;
     for (const QScreen* screen : qApp->screens()) {
-        m_configSdl.fullscreen_monitor->addItem(QString("%1 %2 (%3)").arg(screen->manufacturer(), screen->model(), screen->name()), screen->serialNumber());
+        QString screenName = screen->name().isEmpty() ? i18n("Monitor %1", ix + 1) : QString("%1: %2").arg(ix + 1).arg(screen->name());
+        if (!screen->model().isEmpty()) {
+            screenName.append(QString(" - %1").arg(screen->model()));
+        }
+        if (!screen->manufacturer().isEmpty()) {
+            screenName.append(QString(" (%1)").arg(screen->manufacturer()));
+        }
+        m_configSdl.fullscreen_monitor->addItem(screenName, QString("%1:%2").arg(QString::number(ix), screen->serialNumber()));
+        ix++;
     }
     if (!KdenliveSettings::fullscreen_monitor().isEmpty()) {
         int ix = m_configSdl.fullscreen_monitor->findData(KdenliveSettings::fullscreen_monitor());
         if (ix > -1) {
             m_configSdl.fullscreen_monitor->setCurrentIndex(ix);
+        } else {
+            // Monitor not found, reset
+            m_configSdl.fullscreen_monitor->setCurrentIndex(0);
+            KdenliveSettings::setFullscreen_monitor(QString());
         }
     }
-
-    loadCurrentV4lProfileInfo();
 }
 
+
 void KdenliveSettingsDialog::slotReadAudioDevices()
 {
     QString result = QString(m_readProcess.readAllStandardOutput());
@@ -970,6 +1004,10 @@ void KdenliveSettingsDialog::updateSettings()
         KdenliveSettings::setDefaultprojectfolder(m_configProject.projecturl->url().toLocalFile());
     }
 
+    if (m_configSdl.fullscreen_monitor->currentData().toString() != KdenliveSettings::fullscreen_monitor()) {
+        KdenliveSettings::setFullscreen_monitor(m_configSdl.fullscreen_monitor->currentData().toString());
+    }
+
     if (m_configEnv.capturefolderurl->url().toLocalFile() != KdenliveSettings::capturefolder()) {
         KdenliveSettings::setCapturefolder(m_configEnv.capturefolderurl->url().toLocalFile());
         updateCapturePath = true;
@@ -1216,12 +1254,6 @@ void KdenliveSettingsDialog::updateSettings()
     settingsGroup.writeEntry("dialogSize", QVariant(size()));
 }
 
-void KdenliveSettingsDialog::slotSetFullscreenMonitor()
-{
-    QString value = m_configSdl.fullscreen_monitor->currentData().toString();
-    KdenliveSettings::setFullscreen_monitor(value);
-}
-
 void KdenliveSettingsDialog::slotCheckAlsaDriver()
 {
     QString value = m_configSdl.kcfg_audio_driver->currentData().toString();
