@@ -49,7 +49,7 @@ std::shared_ptr<EffectItemModel> EffectItemModel::construct(const QString &effec
     return self;
 }
 
-std::shared_ptr<EffectItemModel> EffectItemModel::construct(std::unique_ptr<Mlt::Properties> effect, std::shared_ptr<AbstractTreeModel> stack, QString originalDecimalPoint)
+std::shared_ptr<EffectItemModel> EffectItemModel::construct(std::unique_ptr<Mlt::Properties> effect, std::shared_ptr<AbstractTreeModel> stack, const QString &originalDecimalPoint)
 {
     QString effectId = effect->get("kdenlive_id");
     if (effectId.isEmpty()) {
@@ -222,8 +222,7 @@ bool EffectItemModel::hasForcedInOut() const
 
 bool EffectItemModel::isAudio() const
 {
-    AssetListType::AssetType type = EffectsRepository::get()->getType(m_assetId);
-    return  type == AssetListType::AssetType::Audio || type == AssetListType::AssetType::CustomAudio;
+    return EffectsRepository::get()->isAudioEffect(m_assetId);
 }
 
 bool EffectItemModel::isUnique() const
