@@ -5,12 +5,12 @@
 #include "effectstackmodel.hpp"
 #include "assets/keyframes/model/keyframemodellist.hpp"
 #include "core.h"
-#include "mainwindow.h"
 #include "doc/docundostack.hpp"
 #include "effectgroupmodel.hpp"
 #include "effectitemmodel.hpp"
 #include "effects/effectsrepository.hpp"
 #include "macros.hpp"
+#include "mainwindow.h"
 #include "timeline2/model/timelinemodel.hpp"
 #include <profiles/profilemodel.hpp>
 #include <stack>
@@ -19,13 +19,13 @@
 
 EffectStackModel::EffectStackModel(std::weak_ptr<Mlt::Service> service, ObjectId ownerId, std::weak_ptr<DocUndoStack> undo_stack)
     : AbstractTreeModel()
+    , m_masterService(std::move(service))
     , m_effectStackEnabled(true)
     , m_ownerId(std::move(ownerId))
     , m_undoStack(std::move(undo_stack))
     , m_lock(QReadWriteLock::Recursive)
     , m_loadingExisting(false)
 {
-    m_masterService = std::move(service);
 }
 
 std::shared_ptr<EffectStackModel> EffectStackModel::construct(std::weak_ptr<Mlt::Service> service, ObjectId ownerId, std::weak_ptr<DocUndoStack> undo_stack)
@@ -224,7 +224,7 @@ void EffectStackModel::removeEffect(const std::shared_ptr<EffectItemModel> &effe
     }
 }
 
-bool EffectStackModel::copyXmlEffect(QDomElement effect)
+bool EffectStackModel::copyXmlEffect(const QDomElement &effect)
 {
     std::function<bool(void)> undo = []() { return true; };
     std::function<bool(void)> redo = []() { return true; };
@@ -309,8 +309,7 @@ bool EffectStackModel::fromXml(const QDomElement &effectsXml, Fun &undo, Fun &re
     for (int i = 0; i < nodeList.count(); ++i) {
         QDomElement node = nodeList.item(i).toElement();
         const QString effectId = node.attribute(QStringLiteral("id"));
-        AssetListType::AssetType type = EffectsRepository::get()->getType(effectId);
-        bool isAudioEffect = type == AssetListType::AssetType::Audio || type == AssetListType::AssetType::CustomAudio;
+        bool isAudioEffect = EffectsRepository::get()->isAudioEffect(effectId);
         if (isAudioEffect) {
             if (state != PlaylistState::AudioOnly) {
                 continue;
@@ -666,7 +665,7 @@ bool EffectStackModel::adjustStackLength(bool adjustFromEnd, int oldIn, int oldD
                 keyframes->resizeKeyframes(oldIn, oldIn + oldDuration, newIn, out - 1, offset, adjustFromEnd, undo, redo);
                 QModelIndex index = getIndexFromItem(effect);
                 Fun refresh = [effect, index]() {
-                    emit effect->dataChanged(index, index, QVector<int>());
+                    emit effect->dataChanged(index, QModelIndex(), QVector<int>());
                     return true;
                 };
                 refresh();
@@ -872,12 +871,29 @@ void EffectStackModel::registerItem(const std::shared_ptr<TreeItem> &item)
 {
     QWriteLocker locker(&m_lock);
     // qDebug() << "$$$$$$$$$$$$$$$$$$$$$ Planting effect";
-    QModelIndex ix;
     if (!item->isRoot()) {
         auto effectItem = std::static_pointer_cast<EffectItemModel>(item);
         if (!m_loadingExisting) {
             // qDebug() << "$$$$$$$$$$$$$$$$$$$$$ Planting effect in " << m_childServices.size();
             effectItem->plant(m_masterService);
+            // Check if we have an internal effect that needs to stay on top
+            if (m_ownerId.first == ObjectType::Master || m_ownerId.first == ObjectType::TimelineTrack) {
+                // check for subtitle effect
+                auto ms = m_masterService.lock();
+                int ct = ms->filter_count();
+                QVector <int> ixToMove;
+                for (int i = 0; i < ct; i++) {
+                    if (ms->filter(i)->get_int("internal_added") > 0) {
+                        ixToMove << i;
+                    }
+                }
+                std::sort(ixToMove.rbegin(), ixToMove.rend());
+                for (auto &ix : ixToMove) {
+                    if (ix < ct - 1) {
+                        ms->move_filter(ix, ct - 1);
+                    }
+                }
+            }
             for (const auto &service : m_childServices) {
                 // qDebug() << "$$$$$$$$$$$$$$$$$$$$$ Planting CLONE effect in " << (void *)service.lock().get();
                 effectItem->plantClone(service);
@@ -890,7 +906,6 @@ void EffectStackModel::registerItem(const std::shared_ptr<TreeItem> &item)
         } else if (effectId.startsWith(QLatin1String("fadeout")) || effectId.startsWith(QLatin1String("fade_to_"))) {
             m_fadeOuts.insert(effectItem->getId());
         }
-        ix = getIndexFromItem(effectItem);
         if (!effectItem->isAudio() && !m_loadingExisting) {
             pCore->refreshProjectItem(m_ownerId);
             pCore->invalidateItem(m_ownerId);
@@ -978,7 +993,7 @@ bool EffectStackModel::importEffects(const std::shared_ptr<EffectStackModel> &so
     return found;
 }
 
-void EffectStackModel::importEffects(const std::weak_ptr<Mlt::Service> &service, PlaylistState::ClipState state, bool alreadyExist, QString originalDecimalPoint)
+void EffectStackModel::importEffects(const std::weak_ptr<Mlt::Service> &service, PlaylistState::ClipState state, bool alreadyExist, const QString &originalDecimalPoint)
 {
     QWriteLocker locker(&m_lock);
     m_loadingExisting = alreadyExist;
