@@ -34,10 +34,10 @@ void ProxyTask::start(const ObjectId &owner, QObject* object, bool force)
     // See if there is already a task for this MLT service and resource.
     if (pCore->taskManager.hasPendingJob(owner, AbstractTask::PROXYJOB)) {
         delete task;
-        task = 0;
+        task = nullptr;
     }
     if (task) {
-        // Otherwise, start a new audio levels generation thread.
+        // Otherwise, start a new proxy generation thread.
         task->m_isForce = force;
         pCore->taskManager.startTask(owner.second, task);
     }
@@ -315,6 +315,7 @@ void ProxyTask::run()
         if (disableAutorotate || proxyParams.contains(QStringLiteral("-noautorotate"))) {
             // The noautorotate flag must be passed before input source
             parameters << QStringLiteral("-noautorotate");
+            proxyParams.replace(QStringLiteral("-noautorotate"), QString());
         }
         if (proxyParams.contains(QLatin1String("-i "))) {
             // we have some pre-filename parameters, filename will be inserted later
@@ -328,11 +329,9 @@ void ProxyTask::run()
         for (const QString &s : params.split(QLatin1Char(' '), Qt::SkipEmptyParts)) {
 #endif
             QString t = s.simplified();
-            if (t != QLatin1String("-noautorotate")) {
-                parameters << t;
-                if (t == QLatin1String("-i")) {
-                    parameters << source;
-                }
+            parameters << t;
+            if (t == QLatin1String("-i")) {
+                parameters << source;
             }
         }
 
@@ -381,7 +380,6 @@ void ProxyTask::processLogInfo()
 {
     const QString buffer = QString::fromUtf8(m_jobProcess->readAllStandardError());
     m_logDetails.append(buffer);
-    int progress = 0;
     if (m_isFfmpegJob) {
         // Parse FFmpeg output
         if (m_jobDuration == 0) {
@@ -396,6 +394,7 @@ void ProxyTask::processLogInfo()
                 }
             }
         } else if (buffer.contains(QLatin1String("time="))) {
+            int progress = 0;
             QString time = buffer.section(QStringLiteral("time="), 1, 1).simplified().section(QLatin1Char(' '), 0, 0);
             if (!time.isEmpty()) {
                 QStringList numbers = time.split(QLatin1Char(':'));
