@@ -22,6 +22,7 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 TaskManager::TaskManager(QObject *parent)
     : QObject(parent)
     , m_tasksListLock(QReadWriteLock::Recursive)
+    , m_blockUpdates(false)
 {
     int maxThreads = qMin(4, QThread::idealThreadCount() - 1);
     m_taskPool.setMaxThreadCount(qMax(maxThreads, 1));
@@ -33,6 +34,11 @@ TaskManager::~TaskManager()
     slotCancelJobs();
 }
 
+bool TaskManager::isBlocked() const
+{
+    return m_blockUpdates;
+}
+
 void TaskManager::updateConcurrency()
 {
     m_transcodePool.setMaxThreadCount(KdenliveSettings::proxythreads());
@@ -124,6 +130,7 @@ void TaskManager::slotCancelJobs()
 {
     m_tasksListLock.lockForRead();
     // See if there is already a task for this MLT service and resource.
+    m_blockUpdates = true;
     for (const auto &task : m_taskList) {
         for (AbstractTask* t : task.second) {
             // If so, then just add ourselves to be notified upon completion.
@@ -133,6 +140,7 @@ void TaskManager::slotCancelJobs()
     m_tasksListLock.unlock();
     m_taskPool.waitForDone();
     m_transcodePool.waitForDone();
+    m_blockUpdates = false;
     updateJobCount();
 }
 
