@@ -424,6 +424,9 @@ Monitor::Monitor(Kdenlive::MonitorId id, MonitorManager *manager, QWidget *paren
         m_audioMeterWidget->setVisibility(false);
     } else {
         m_audioMeterWidget->setVisibility((KdenliveSettings::monitoraudio() & m_id) != 0);
+        if (id == Kdenlive::ProjectMonitor) {
+            connect(m_audioMeterWidget, &MonitorAudioLevel::audioLevelsAvailable, pCore.get(), &Core::audioLevelsAvailable);
+        }
     }
 
     // Trimming tool bar buttons
@@ -688,7 +691,11 @@ void Monitor::slotForceSize(QAction *a)
     updateGeometry();
 }
 
-void Monitor::buildBackgroundedProducer(int pos) {
+void Monitor::buildBackgroundedProducer(int pos)
+{
+    if (m_controller == nullptr) {
+        return;
+    }
     if (KdenliveSettings::monitor_background() != "black") {
         Mlt::Tractor trac(pCore->getCurrentProfile()->profile());
         QString color = QString("color:%1").arg(KdenliveSettings::monitor_background());
@@ -696,6 +703,7 @@ void Monitor::buildBackgroundedProducer(int pos) {
         int maxLength = m_controller->originalProducer()->get_length();
         bg->set("length", maxLength);
         bg->set("out", maxLength - 1);
+        bg->set("mlt_image_format", "rgba");
         trac.set_track(*bg.get(), 0);
         trac.set_track(*m_controller->originalProducer().get(), 1);
         QString composite = TransitionsRepository::get()->getCompositingTransition();
@@ -709,7 +717,6 @@ void Monitor::buildBackgroundedProducer(int pos) {
     }
 }
 
-
 void Monitor::updateMarkers()
 {
     if (m_markerMenu) {
@@ -949,10 +956,14 @@ void Monitor::slotSwitchFullScreen(bool minimizeOnly)
                         m_glWidget->setParent(nullptr);
                         m_glWidget->move(screenRect.topLeft());
                         m_glWidget->resize(screenRect.size());
+                        screenFound = true;
                         break;
                     }
                 }
             }
+            if (!screenFound) {
+                m_glWidget->setParent(nullptr);
+            }
         } else {
             m_glWidget->setParent(nullptr);
         }
@@ -1290,9 +1301,9 @@ void Monitor::checkOverlay(int pos)
     }
 
     if (model) {
-        bool found = false;
-        CommentedTime marker = model->getMarker(GenTime(pos, pCore->getCurrentFps()), &found);
-        if (found) {
+        int mid = model->markerIdAtFrame(pos);
+        if (mid > -1) {
+            CommentedTime marker = model->markerById(mid);
             overlayText = marker.comment();
             color = model->markerTypes.at(marker.markerType());
         }
@@ -1625,6 +1636,9 @@ void Monitor::slotOpenClip(const std::shared_ptr<ProjectClip> &controller, int i
             disconnect(m_controller.get(), &ProjectClip::boundsChanged, m_glMonitor->getControllerProxy(), &MonitorProxy::updateClipBounds);
             disconnect(m_controller.get(), &ProjectClip::registeredClipChanged, m_controller.get(), &ProjectClip::checkClipBounds);
         }
+    } else if (controller == nullptr) {
+        // Nothing to do
+        return;
     }
     disconnect(this, &Monitor::seekPosition, this, &Monitor::seekRemap);
     m_controller = controller;
@@ -1797,11 +1811,13 @@ const QString Monitor::activeClipId()
 
 void Monitor::slotPreviewResource(const QString &path, const QString &title)
 {
-    if (!QUrl::fromUserInput(path).isLocalFile()) {
-        warningMessage(i18n("It maybe takes a while until the preview is loaded"), 15000);
+    if (isPlaying()) {
+        stop();
     }
+    QApplication::processEvents();
     slotOpenClip(nullptr);
     m_streamAction->setVisible(false);
+    // TODO: direct loading of the producer blocks UI, we should use a task to load the producer
     m_glMonitor->setProducer(path);
     m_timePos->setRange(0, m_glMonitor->producer()->get_length() - 1);
     m_glMonitor->getControllerProxy()->setClipProperties(-1, ClipType::Unknown, false, title);
@@ -2021,10 +2037,13 @@ void Monitor::updateAudioForAnalysis()
 
 void Monitor::onFrameDisplayed(const SharedFrame &frame)
 {
+    emit m_monitorManager->frameDisplayed(frame);
+    if (m_id == Kdenlive::ProjectMonitor) {
+        emit pCore->updateMixerLevels(frame.get_position());
+    }
     if (!m_glMonitor->checkFrameNumber(frame.get_position(), m_playAction->isActive())) {
         updatePlayAction(false);
     }
-    emit m_monitorManager->frameDisplayed(frame);
 }
 
 void Monitor::checkDrops()
@@ -2359,7 +2378,7 @@ void Monitor::slotEditInlineMarker()
         }
         QString newComment = root->property("markerText").toString();
         bool found = false;
-        CommentedTime oldMarker = model->getMarker(m_timePos->gentime(), &found);
+        CommentedTime oldMarker = model->getMarker(m_timePos->getValue(), &found);
         if (!found || newComment == oldMarker.comment()) {
             // No change
             return;
@@ -2403,7 +2422,7 @@ void Monitor::slotSwitchAudioMonitor()
 
 void Monitor::displayAudioMonitor(bool isActive)
 {
-    bool enable = isActive && ((KdenliveSettings::monitoraudio() & m_id) != 0);
+    bool enable = isActive && ((KdenliveSettings::monitoraudio() & m_id) != 0 || (m_id == Kdenlive::ProjectMonitor && pCore->audioMixerVisible));
     if (enable) {
         connect(m_monitorManager, &MonitorManager::frameDisplayed, m_audioMeterWidget, &ScopeWidget::onNewFrame, Qt::UniqueConnection);
     } else {
