@@ -8,7 +8,7 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #define SLIDESHOWCLIP_H
 
 #include "definitions.h"
-#include "timecode.h"
+#include "utils/timecode.h"
 #include "ui_slideshowclip_ui.h"
 
 #include <KIO/PreviewJob>
@@ -34,6 +34,10 @@ public:
     QString lumaFile() const;
     int softness() const;
     QString animation() const;
+    /** @brief Should we add a low-pass (blur) filter */
+    int lowPass() const;
+    /** @brief The selected image extension */
+    const QString extension() const;
 
     /** @brief Get the image frame number from a file path, for example image_047.jpg will return 47. */
     static int getFrameNumberFromPath(const QUrl &path);
